@@ -844,7 +844,7 @@ static void position_menu(GtkMenu *menu, gint *x, gint *y, gboolean *push_in, Me
 }
 #endif
 
-void gMenu::doPopup(bool move, int x, int y)
+void gMenu::doPopup(bool move, int x, int y, gControl *ref)
 {
 	if (!_popup)
 		return;
@@ -881,7 +881,7 @@ void gMenu::doPopup(bool move, int x, int y)
 	else
 	{
 		event->button.button = 1;
-		event->button.window = gtk_widget_get_window(window()->border);
+		event->button.window = ref ? gtk_widget_get_window(ref->window()->border) : gtk_widget_get_window(window()->border);
 	}
 	
 	gdk_event_set_device(event, gMouse::getPointer());
@@ -947,9 +947,9 @@ void gMenu::doPopup(bool move, int x, int y)
 		MAIN_do_iteration(false);
 }
 
-void gMenu::popup(int x, int y)
+void gMenu::popup(int x, int y, gControl *ref)
 {
-	doPopup(true, x, y);
+	doPopup(true, x, y, ref);
 }
 
 void gMenu::popup()
