@@ -333,7 +333,10 @@ static void trans_identifier(int index, bool point, PATTERN next)
 				if (COMP_version >= 0x03180000 && constant->value >= -128 && constant->value <= 127)
 					CODE_push_float(constant->value);
 				else
+				{
 					CODE_push_number(constant->value);
+					type = T_INTEGER;
+				}
 			}
 			else
 				CODE_push_const(sym->global.value);
@@ -473,9 +476,10 @@ static void trans_operation(short op, short nparam, PATTERN previous)
 
 		case RST_ADD:
 			type = Max(get_type_id(0, nparam), get_type_id(1, nparam));
-			ftype = TYPE_make_simple(type);
 			if (type == T_DATE)
-				type = T_FLOAT;
+				ftype = TYPE_make_simple(T_FLOAT);
+			else
+				ftype = TYPE_make_simple(type);
 			break;
 
 		case RST_AND:
@@ -520,6 +524,18 @@ static void trans_operation(short op, short nparam, PATTERN previous)
 			break;
 
 		case RST_DIV:
+			type = Max(get_type_id(0, nparam), get_type_id(1, nparam));
+			if (type != T_SINGLE)
+			{
+				if (type <= T_FLOAT)
+					type = T_FLOAT;
+				else
+					type = T_VARIANT;
+			}
+			ftype = TYPE_make_simple(type);
+			break;
+
+		case RST_FLEX:
 			type = Max(get_type_id(0, nparam), get_type_id(1, nparam));
 			if (type <= T_FLOAT)
 				type = T_FLOAT;
@@ -613,11 +629,11 @@ static void trans_operation(short op, short nparam, PATTERN previous)
 				type = RST_SAME;
 			}
 			else
-				CODE_add_sub(info->code, info->subcode, nparam, TYPE_get_id(ftype));
+				CODE_add_sub(info->code, info->subcode, nparam, type);
 			break;
 			
 		case OP_PLUS:
-			CODE_add_sub(info->code, info->subcode, nparam, TYPE_get_id(ftype));
+			CODE_add_sub(info->code, info->subcode, nparam, type);
 			break;
 
 		case OP_AMP:
